@@ -8,8 +8,8 @@ from PySide6.QtCore import QFile, QIODevice, Qt
 from PySide6.QtGui import QCursor, QMovie
 from PySide6.QtUiTools import QUiLoader
 from PySide6.QtWidgets import QButtonGroup, QMainWindow, QFileDialog, QDialog
-from dependency_injector.wiring import inject, Provide, as_, as_float
 
+from plagdef.config import settings
 from plagdef.gui.model import ResultsTableModel, DocumentPairMatches
 from plagdef.model.models import MatchType
 from plagdef.model.util import version, truncate
@@ -59,8 +59,7 @@ class View:
 
 
 class HomeView(View):
-    @inject
-    def __init__(self, lang: str = Provide['config.default.lang']):
+    def __init__(self, lang=settings['lang']):
         self.widget = _load_ui_file(Path(UI_FILES['home_widget']))
         self._configure(lang)
 
@@ -280,8 +279,35 @@ class MatchesDialog:
     def _configure(self):
         self.widget.doc1_label.setCursor(QCursor(Qt.PointingHandCursor))
         self.widget.doc2_label.setCursor(QCursor(Qt.PointingHandCursor))
+        self.widget.reanalyze_button.setCursor(QCursor(Qt.PointingHandCursor))
+        self.widget.sim_slider.valueChanged.connect(lambda val: self._update_label(val))
+
+    def _update_label(self, sim):
+        self.widget.value_label.setText(str(sim / 10))
+
+    @property
+    def doc1_path(self):
+        return self._doc_pair_matches.doc1.path
+
+    @property
+    def doc2_path(self):
+        return self._doc_pair_matches.doc2.path
+
+    @property
+    def sim_threshold(self) -> float:
+        return float(self.widget.value_label.text())
+
+    @property
+    def match_type(self):
+        return self._doc_pair_matches.matches[0].type
 
     def open(self, doc_pair_matches: DocumentPairMatches):
+        self.widget.value_label.setText(str(settings['min_cos_sim']))
+        self.widget.sim_slider.setValue(settings['min_cos_sim'] * 10)
+        self.set_data(doc_pair_matches)
+        self.widget.exec_()
+
+    def set_data(self, doc_pair_matches):
         self._doc_pair_matches = doc_pair_matches
         self.widget.doc1_label.setText(truncate(self._doc_pair_matches.doc1.name, 50))
         self.widget.doc1_path.setText(f'({truncate(self._doc_pair_matches.doc1.path, 65)})')
@@ -289,7 +315,6 @@ class MatchesDialog:
         self.widget.doc2_path.setText(f'({truncate(self._doc_pair_matches.doc2.path, 65)})')
         self._selected = 0
         self._show_match()
-        self.widget.exec_()
 
     def _show_match(self):
         doc1, doc2 = self._doc_pair_matches.doc1, self._doc_pair_matches.doc2
@@ -303,11 +328,12 @@ class MatchesDialog:
         if self._selected + 1 == len(self._doc_pair_matches):
             self.widget.next_button.setVisible(False)
 
-    def register_for_signals(self, prev_match=None, next_match=None, open_doc=None):
+    def register_for_signals(self, prev_match=None, next_match=None, open_doc=None, reanalyze=None):
         self.widget.prev_button.clicked.connect(lambda: prev_match())
         self.widget.next_button.clicked.connect(lambda: next_match())
         self.widget.doc1_label.clicked.connect(lambda: open_doc(self._doc_pair_matches.doc1.path))
         self.widget.doc2_label.clicked.connect(lambda: open_doc(self._doc_pair_matches.doc2.path))
+        self.widget.reanalyze_button.clicked.connect(lambda: reanalyze())
 
     def prev_match(self):
         self._selected -= 1
@@ -317,6 +343,10 @@ class MatchesDialog:
         self._selected += 1
         self._show_match()
 
+    def reanalyzing(self, loading: bool):
+        self.widget.sim_slider.setEnabled(not loading)
+        self.widget.reanalyze_button.setEnabled(not loading)
+
 
 class MessageDialog:
     def __init__(self, text):
@@ -341,9 +371,7 @@ class SettingsDialog:
     def ocr(self) -> bool:
         return self.widget.ocr_check_box.isChecked()
 
-    @inject
-    def open(self, ocr: bool = Provide['config.default.ocr', as_(bool)],
-             sim: float = Provide['config.default.min_cos_sim', as_float()]):
+    def open(self, ocr=settings['ocr'], sim=settings['min_cos_sim']):
         self.widget.ocr_check_box.setChecked(ocr)
         self.widget.value_label.setText(str(sim))
         self.widget.sim_slider.setValue(sim * 10)
